@@ -2,18 +2,22 @@
 #' 
 #' @title Calculates the Addon amount
 #' @param trades_tree A tree structure with the input trades
-#' @param MF (Optional) The Maturity Factor based on the collateral agreement  
+#' @param MF (Optional) The Maturity Factor based on the collateral agreement
+#' @param simplified (optional) When TRUE, the add-ons will be calculated as per the simplified SA-CCR
+#' @param OEM (optional) When TRUE, the add-ons will be calculated as per the Original Exposure Method
 #' @return The aggregate amount of the addon summed up for all the asset classes
 #' @export
 #' @author Tasos Grivas <tasos@@openriskcalculator.com>
-#' @references Basel Committee: The standardised approach for measuring counterparty credit risk exposures
-#' http://www.bis.org/publ/bcbs279.htm
+#' @references Regulation (EU) 2019/876 of the European Parliament and of the Council of 20 May 2019
+#' http://data.europa.eu/eli/reg/2019/876/oj
 #' 
-CalcAddon <- function(trades_tree, MF)  {
+CalcAddon <- function(trades_tree, MF, simplified = FALSE, OEM = FALSE)  {
   ## function which will calculate the Add-On for all the trade classes
   
   superv <- LoadSupervisoryData()
   
+  if(simplified)  superv[,'Correlation']=1
+  
   asset_classes = trades_tree$`Asset Classes`$children
   asset_class_names = names(asset_classes)
   trades_tree$addon = 0
@@ -44,19 +48,60 @@ CalcAddon <- function(trades_tree, MF)  {
           ccypairs_trade = ccypairs_trades[[ccypairs_trades_names[l]]]
           ccypairs_trade$exposure_details = SingleTradeAddon(ccypairs_trade$trade,MF)
           # aggregating the add-on contribution for a specific hedging set
-          ccypairs[[ccypairs_names[j]]]$add_on <- ccypairs[[ccypairs_names[j]]]$add_on + ccypairs_trade$exposure_details$effective_notional
+          if(OEM)
+          {   ccypairs[[ccypairs_names[j]]]$add_on <- ccypairs[[ccypairs_names[j]]]$add_on + ccypairs_trade$trade_details$Notional*ccypairs_trade$trade_details$Ei
+          }else
+          {   ccypairs[[ccypairs_names[j]]]$add_on <- ccypairs[[ccypairs_names[j]]]$add_on + ccypairs_trade$exposure_details$effective_notional          }
+          
 
         }
-        factor_mult = CalculateFactorMult(ccypairs_names[j])
-        # getting the supervisory factor
-        supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==ccypairs_trade$trade$TradeGroup]
+        if(OEM)
+        {  supervisory_factor = 0.04
+        }else
+        {
+          factor_mult = CalculateFactorMult(ccypairs_names[j])
+          # getting the supervisory factor
+          supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==ccypairs_trade$trade$TradeGroup]
+        }
         ccypairs[[ccypairs_names[j]]]$supervisory_factor = supervisory_factor
         ccypairs_addon[j] = supervisory_factor*ccypairs[[ccypairs_names[j]]]$add_on
         ccypairs[[ccypairs_names[j]]]$add_on = abs(ccypairs_addon[j])
       }
       asset_class_node$addon = sum(abs(ccypairs_addon))
       trades_tree$addon = trades_tree$addon + asset_class_node$addon
-    }  else if(asset_class_names[i]=='IRD')
+    }else if(asset_class_names[i]=='OtherExposure')
+    {
+      riskfactors   <- asset_class_node$`Other SubClasses`$children
+      # for the FX case the Hedging sets will be created based on the ccy pair
+      riskfactors_names  <- names(riskfactors)
+      riskfactors_addon <- array(data<-0,dim<-length(riskfactors))
+      # going through all the ccy pairs found
+      for (j  in 1:length(riskfactors_names))
+      {
+        
+        riskfactors_trades  <- riskfactors[[riskfactors_names[j]]]$Trades$children
+        riskfactors[[riskfactors_names[j]]]$add_on = 0
+        riskfactors_trades_names = names(riskfactors_trades)
+        
+        # for each of the trade calculate the Adjusted Notional and their contribution to the addon of the hedging set
+        for (l in 1:length(riskfactors_trades_names))
+        {
+          riskfactors_trade = riskfactors_trades[[riskfactors_trades_names[l]]]
+          riskfactors_trade$exposure_details = SingleTradeAddon(riskfactors_trade$trade,MF)
+          # aggregating the add-on contribution for a specific hedging set
+          riskfactors[[riskfactors_names[j]]]$add_on <- riskfactors[[riskfactors_names[j]]]$add_on + riskfactors_trade$exposure_details$effective_notional
+          
+        }
+        factor_mult = CalculateFactorMult(riskfactors_names[j])
+        # getting the supervisory factor
+        supervisory_factor <- 0.08*factor_mult
+        riskfactors[[riskfactors_names[j]]]$supervisory_factor = supervisory_factor
+        riskfactors_addon[j] = supervisory_factor*riskfactors[[riskfactors_names[j]]]$add_on
+        riskfactors[[riskfactors_names[j]]]$add_on = abs(riskfactors_addon[j])
+      }
+      asset_class_node$addon = sum(abs(riskfactors_addon))
+      trades_tree$addon = trades_tree$addon + asset_class_node$addon
+    }else if(asset_class_names[i]=='IRD')
     {
       
       # picking up the currencies found in the IRD trades which will be the first-level grouping applied 
@@ -77,9 +122,14 @@ CalcAddon <- function(trades_tree, MF)  {
           
           timebuckets_trades_names = names(timebuckets_trades)
           
-          factor_mult = CalculateFactorMult(currencies_names[j])
+          if(OEM)
+          {  supervisory_factor = 0.005
+          }else
+          {
+            factor_mult = CalculateFactorMult(currencies_names[j])
+            supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==timebuckets_trades[[1]]$trade$TradeGroup&superv$SubClass==timebuckets_trades[[1]]$trade$SubClass]
+          }
           
-          supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==timebuckets_trades[[1]]$trade$TradeGroup&superv$SubClass==timebuckets_trades[[1]]$trade$SubClass]
           currencies[[currencies_names[j]]]$supervisory_factor = supervisory_factor
           
           exotic_identifier = ''
@@ -88,9 +138,12 @@ CalcAddon <- function(trades_tree, MF)  {
           {
             timebuckets_trade = timebuckets_trades[[timebuckets_trades_names[l]]]
             timebuckets_trade$exposure_details = SingleTradeAddon(timebuckets_trade$trade,MF)
-
-            currencies_buckets[[currencies_buckets_names[k]]]$effective_notional = currencies_buckets[[currencies_buckets_names[k]]]$effective_notional + timebuckets_trade$exposure_details$effective_notional
             
+            if(OEM)
+            {   currencies_buckets[[currencies_buckets_names[k]]]$effective_notional = currencies_buckets[[currencies_buckets_names[k]]]$effective_notional + timebuckets_trade$trade_details$Notional*timebuckets_trade$trade_details$Ei
+            }else
+            {   currencies_buckets[[currencies_buckets_names[k]]]$effective_notional = currencies_buckets[[currencies_buckets_names[k]]]$effective_notional + timebuckets_trade$exposure_details$effective_notional          }
+
             if(!is.null(timebuckets_trade$trade$Exotic_Type)&length(timebuckets_trade$trade$Exotic_Type)!=0)
             {
               if(exotic_identifier!='')
@@ -109,7 +162,12 @@ CalcAddon <- function(trades_tree, MF)  {
           }
 
           # aggregating the add-on timebuckets recognizing correlation between each time bucket
-          currencies[[currencies_names[j]]]$effective_notional = (sum(currencies_buckets[["1"]]$effective_notional^2,currencies_buckets[["2"]]$effective_notional^2,currencies_buckets[["3"]]$effective_notional^2,1.4*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["3"]]$effective_notional,1.4*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["1"]]$effective_notional,0.6*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["1"]]$effective_notional,na.rm = TRUE))^0.5
+          if(simplified)
+            currencies[[currencies_names[j]]]$effective_notional  <- sum(abs(unlist(lapply(currencies_buckets,function(x) x$effective_notional))),na.rm = TRUE)
+          else
+            currencies[[currencies_names[j]]]$effective_notional = (sum(currencies_buckets[["1"]]$effective_notional^2,currencies_buckets[["2"]]$effective_notional^2,currencies_buckets[["3"]]$effective_notional^2,1.4*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["3"]]$effective_notional,1.4*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["1"]]$effective_notional,0.6*currencies_buckets[["2"]]$effective_notional*currencies_buckets[["1"]]$effective_notional,na.rm = TRUE))^0.5
+          
+          
           currencies[[currencies_names[j]]]$addon <- supervisory_factor*currencies[[currencies_names[j]]]$effective_notional
           
         }
@@ -139,11 +197,22 @@ CalcAddon <- function(trades_tree, MF)  {
         {
           refEntities_trade = refEntities_trades[[refEntities_trades_names[k]]]
           refEntities_trade$exposure_details = SingleTradeAddon(refEntities_trade$trade,MF)
-          refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$exposure_details$effective_notional
+          
+          if(OEM)
+          {  refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$trade_details$Notional*refEntities_trade$trade_details$Ei
+          }else
+          {  refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$exposure_details$effective_notional          }
         }
-        factor_mult = CalculateFactorMult(refEntities_names[j])
-        AssetClass<-paste(refEntities_trade$trade$TradeGroup,refEntities_trade$trade$TradeType,sep="")
-        supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]
+        
+        AssetClass<-ifelse(class(refEntities_trade$trade)=='CDS','CreditSingle','CreditIndex')
+        
+        if(OEM)
+        {  supervisory_factor = 0.06
+        }else
+        {  factor_mult = CalculateFactorMult(refEntities_names[j])
+           supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]
+        }
+        
         refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on*supervisory_factor
         supervisory_corel[j]  <- superv$Correlation[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]
         refEntities_addon[j] = refEntities[[refEntities_names[j]]]$add_on
@@ -161,7 +230,7 @@ CalcAddon <- function(trades_tree, MF)  {
       AssetClass <-'Commodity'
       
       HedgingSets   <- asset_class_node$`Hedging Sets`$children
-      # for the FX case the Hedging sets will be created based on the ccy pair
+      
       HedgingSets_names  <- names(HedgingSets)
       
       # for the commodities case the Hedging sets will be created based on the commodity sector on a first
@@ -187,12 +256,19 @@ CalcAddon <- function(trades_tree, MF)  {
           {
             com_types_trade = com_types_trades[[com_types_trades_names[l]]]
             com_types_trade$exposure_details = SingleTradeAddon(com_types_trade$trade,MF)
-            # aggregating the add-on contribution for a specific hedging set
-            com_types[[com_types_names[k]]]$addon <- com_types[[com_types_names[k]]]$addon + com_types_trade$exposure_details$effective_notional
+            
+            if(OEM)
+            {  com_types[[com_types_names[k]]]$addon <- com_types[[com_types_names[k]]]$addon + com_types_trade$exposure_details$effective_notional  + com_types_trade$trade_details$Notional*com_types_trade$trade_details$Ei
+            }else
+            {  com_types[[com_types_names[k]]]$addon <- abs(com_types[[com_types_names[k]]]$addon + com_types_trade$exposure_details$effective_notional)}
+            
             com_types[[com_types_names[k]]]$effective_notional = com_types[[com_types_names[k]]]$effective_notional + com_types_trade$exposure_details$effective_notional
           }
-          factor_mult = CalculateFactorMult(HedgingSets_names[j])
-          supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==AssetClass&(superv$SubClass==com_types_trade$trade$SubClass|superv$SubClass==com_types_trade$trade$commodity_type)]
+          if(OEM)
+            factor_mult = 1
+          else
+            factor_mult = CalculateFactorMult(HedgingSets_names[j])
+          supervisory_factor <- factor_mult*ifelse(com_types_trade$trade$commodity_type=='Electricity',0.4,0.18)
           com_types[[com_types_names[k]]]$addon <- com_types[[com_types_names[k]]]$addon*supervisory_factor
           com_types[[com_types_names[k]]]$supervisory_factor = supervisory_factor
           com_types_addon = com_types_addon + com_types[[com_types_names[k]]]$addon
@@ -200,7 +276,7 @@ CalcAddon <- function(trades_tree, MF)  {
           #com_types[[com_types_names[k]]]$com_types_addon = com_types_addon
           
         }
-        supervisory_corel     <- superv$Correlation[superv$Asset_Class==AssetClass&(superv$SubClass==com_types_trade$trade$SubClass|superv$SubClass==com_types_trade$trade$commodity_type)]
+        supervisory_corel     <- 0.4
         HedgingSets[[HedgingSets_names[j]]]$addon  <- sqrt((com_types_addon*supervisory_corel)^2 + (1-supervisory_corel^2)*com_types_addon_sq)
         HedgingSets[[HedgingSets_names[j]]]$supervisory_corel = supervisory_corel
         HedgingSets_addon = HedgingSets_addon + HedgingSets[[HedgingSets_names[j]]]$addon
@@ -227,11 +303,19 @@ CalcAddon <- function(trades_tree, MF)  {
         {
           refEntities_trade = refEntities_trades[[refEntities_trades_names[k]]]
           refEntities_trade$exposure_details = SingleTradeAddon(refEntities_trade$trade,MF)
-          refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$exposure_details$effective_notional
+          if(OEM)
+          {  refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$exposure_details$effective_notional
+          }else
+          {  refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on  + refEntities_trade$exposure_details$effective_notional          }
+          
         }
-        factor_mult = CalculateFactorMult(refEntities_names[j])
         AssetClass<-paste(refEntities_trade$trade$TradeGroup,refEntities_trade$trade$TradeType,sep="")
-        supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]
+        
+        if(OEM)
+        {  supervisory_factor = 0.32
+        }else
+        { factor_mult = CalculateFactorMult(refEntities_names[j])
+          supervisory_factor <- factor_mult*superv$Supervisory_factor[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]}
         refEntities[[refEntities_names[j]]]$add_on <- refEntities[[refEntities_names[j]]]$add_on*supervisory_factor
         supervisory_corel[j]  <- superv$Correlation[superv$Asset_Class==AssetClass&superv$SubClass==refEntities_trade$trade$SubClass]
         refEntities_addon[j] = refEntities[[refEntities_names[j]]]$add_on
