@@ -2,7 +2,7 @@ GroupEquityTrades = function(group_trades, trade_classes_tree,hedging_set_name)
 {
   # for the Credit case the Hedging sets will be created based on the reference entity
   refEntities   <- unique(lapply(group_trades, function(x) (if(length(x$Issuer)!= 0) x$Issuer)))
-  refEntities = c(refEntities, unique(lapply(group_trades, function(x) (if(length(x$Underlying_Index)!= 0) x$Underlying_Index))))
+  refEntities = c(refEntities, unique(lapply(group_trades, function(x) (if(length(x$Underlying_Instrument)!= 0) x$Underlying_Instrument))))
   if(!missing(hedging_set_name))
   {
     if(substr(hedging_set_name,1,4)=="Vol_"||substr(hedging_set_name,1,6)=="Basis_")
@@ -23,7 +23,7 @@ if(length(trade_classes_tree[["Reference Entities"]])==0)
 
 for (j  in 1:length(refEntities))
 {
-  refEntities_trades  <- group_trades[sapply(group_trades, function(x) ((ifelse(length(x$Issuer== refEntities[[j]])!=0,x$Issuer == refEntities[[j]],FALSE) ) | (ifelse(length(x$Underlying_Index== refEntities[[j]])!=0, x$Underlying_Index == refEntities[[j]],FALSE))))]
+  refEntities_trades  <- group_trades[sapply(group_trades, function(x) ((ifelse(length(x$Issuer== refEntities[[j]])!=0,x$Issuer == refEntities[[j]],FALSE) ) | (ifelse(length(x$Underlying_Instrument== refEntities[[j]])!=0, x$Underlying_Instrument == refEntities[[j]],FALSE))))]
   refEntities_tree[[j]] = refEntities_tree_name$AddChild(temp_refEntities[[j]])
   
   trades_tree_name = refEntities_tree[[j]]$AddChild("Trades")
